{% extends "base.html" %}
{% load tags %}

{% block breadcrumb %}
<ul class="breadcrumb">
    <li><a href="{% url app_label|add:'-'|add:actual_model_name|add:'-list' %}">{{pluralized_model_name|title}}</a></li>
    <li><a href="{% url app_label|add:'-'|add:actual_model_name|add:'-detail' object.id %}">{{object}}</a></li>
    <li class="active">Update {{object}}</li>
</ul>
{% endblock %}


{% block main_content %}

<div class='container'>
	<h3>Update {{actual_model_name|title}}</h3>
	<hr/>
	{% include "widgets/form.html" %}
</div>

{% endblock %}
